@@ -14,7 +14,7 @@
 #include "data_row_id.h"
 #include "data_uuid.h"
 #include "u8/u8_error.h"
-#include "util/string/utf8stringbuf.h"
+#include "utf8stringbuf/utf8stringbuf.h"
 #include <stdint.h>
 #include <stdbool.h>
 
