@@ -1,4 +1,4 @@
-/* File: gui_main_window.h; Copyright and License: see below */
+ /* File: gui_main_window.h; Copyright and License: see below */
 
 #ifndef GUI_MAIN_WINDOW_H
 #define GUI_MAIN_WINDOW_H
@@ -10,7 +10,7 @@
  */
 
 #include "gui_simple_message_to_user.h"
-#include "sketch_area/gui_sketch_area.h"
+#include "sketch/gui_sketch_area.h"
 #include "gui_toolbox.h"
 #include "gui_resources.h"
 #include "gui_attributes_editor.h"
@@ -18,10 +18,10 @@
 #include "gui_file_export_dialog.h"
 #include "gui_search_request.h"
 #include "gui_search_runner.h"
-#include "storage/data_database.h"
+#include "io_data_file.h"
 #include "storage/data_change_message.h"
 #include "ctrl_controller.h"
-#include "util/observer/observer.h"
+#include "observer/observer.h"
 #include <gtk/gtk.h>
 
 /*!
@@ -37,7 +37,10 @@ struct gui_main_window_struct {
     observer_t *window_open_observer;  /*!< pointer to external observer_t listener object */
     gui_file_use_db_dialog_t file_use_db_dialog;  /*!<  own instance of gui_file_use_db_dialog_t */
     gui_file_export_dialog_t file_export_dialog;  /*!<  own instance of gui_file_export_dialog_t */
-    data_database_t *database;  /*!< pointer to external database */
+    io_data_file_t *data_file;  /*!< pointer to external data_file */
+#ifndef NDEBUG
+    ctrl_controller_t *controller;  /*!< pointer to external controller, which can test the database in debug mode */
+#endif  /* not NDEBUG */
 
     GtkWidget *window;
     GtkWidget *main_stack_column;
@@ -46,6 +49,7 @@ struct gui_main_window_struct {
     GtkWidget *sketcharea;
 
     GtkWidget *tool_row;
+
     GtkWidget *file_new_db_icon;
     GtkButton *file_new_db;
     GtkWidget *file_use_db_icon;
@@ -56,18 +60,22 @@ struct gui_main_window_struct {
     */
     GtkWidget *file_export_icon;
     GtkButton *file_export;
-    GtkWidget *file_new_window_icon;
-    GtkButton *file_new_window;
+
     GtkWidget *tool_sect_1_icon;
-    GtkWidget *tool_navigate_icon;
-    GtkWidget *tool_navigate;
-    GtkWidget *tool_edit_icon;
-    GtkWidget *tool_edit;
-    GtkWidget *tool_create_icon;
-    GtkWidget *tool_create;
-    GtkWidget *tool_search_icon;
-    GtkWidget *tool_search;
+
+    GtkWidget *view_new_window_icon;
+    GtkButton *view_new_window;
+    GtkWidget *view_navigate_icon;
+    GtkWidget *view_navigate;
+    GtkWidget *view_edit_icon;
+    GtkWidget *view_edit;
+    GtkWidget *view_create_icon;
+    GtkWidget *view_create;
+    GtkWidget *view_search_icon;
+    GtkWidget *view_search;
+
     GtkWidget *tool_sect_2_icon;
+
     GtkWidget *edit_undo_icon;
     GtkButton *edit_undo;
     GtkWidget *edit_redo_icon;
@@ -108,8 +116,8 @@ struct gui_main_window_struct {
     GtkWidget *type_icon_grid;
     GtkWidget *stereotype_label;
     GtkWidget *stereotype_entry;
-    GtkWidget *edit_commit_icon;
-    GtkWidget *edit_commit_button;
+    GtkWidget *file_save_icon;
+    GtkWidget *file_save_button;
 
     GtkWidget *search_row;
     GtkWidget *search_label;
@@ -132,7 +140,7 @@ typedef struct gui_main_window_struct gui_main_window_t;
  *
  *  \param this_ pointer to own object attributes
  *  \param controller pointer to a controller object which can modify the database
- *  \param database pointer to a database object
+ *  \param data_file pointer to a data_file object
  *  \param db_reader pointer to a database reader object
  *  \param res pointer to a resource provider
  *  \param gtk_app the gtk application object
@@ -141,7 +149,7 @@ typedef struct gui_main_window_struct gui_main_window_t;
  */
 void gui_main_window_init( gui_main_window_t *this_,
                            ctrl_controller_t *controller,
-                           data_database_t *database,
+                           io_data_file_t *data_file,
                            data_database_reader_t *db_reader,
                            gui_resources_t *res,
 #if ( GTK_MAJOR_VERSION >= 4 )
@@ -217,6 +225,19 @@ void gui_main_window_new_db_btn_callback( GtkWidget* button, gpointer data );
  */
 void gui_main_window_open_db_btn_callback( GtkWidget* button, gpointer data );
 
+/*!
+ *  \brief callback that informs that the save button was pressed
+ */
+void gui_main_window_save_btn_callback( GtkButton *button, gpointer user_data );
+
+#if ( GTK_MAJOR_VERSION >= 4 )
+/*!
+ *  \brief callback that informs that the save shortcut was activated
+ */
+gboolean gui_main_window_save_shortcut_callback( GtkWidget* widget, GVariant* args, gpointer user_data );
+#else
+#endif
+
 /*!
  *  \brief callback that informs that the export button was pressed
  */
