@@ -1,11 +1,12 @@
 /* File: gui_simple_message_to_user.c; Copyright and License: see below */
 
 #include "gui_simple_message_to_user.h"
+#include "gui_error_info_printer.h"
 #include "trace/trace.h"
 #include "tslog/tslog.h"
 #include "meta/meta_info.h"
 #include "meta/meta_version.h"
-#include "utf8stringbuf/utf8stringbuf.h"
+#include "u8/u8_error.h"
 #include <stdbool.h>
 #include <assert.h>
 
@@ -232,6 +233,7 @@ void gui_simple_message_to_user_show_message_with_quantity ( gui_simple_message_
     TRACE_END();
 }
 
+#if 0
 void gui_simple_message_to_user_show_message_with_line ( gui_simple_message_to_user_t *this_,
                                                          gui_simple_message_type_t type_id,
                                                          const gui_simple_message_content_position_t *content_id,
@@ -265,6 +267,7 @@ void gui_simple_message_to_user_show_message_with_line ( gui_simple_message_to_u
 
     TRACE_END();
 }
+#endif
 
 void gui_simple_message_to_user_show_message_with_name ( gui_simple_message_to_user_t *this_,
                                                          gui_simple_message_type_t type_id,
@@ -287,6 +290,14 @@ void gui_simple_message_to_user_show_message_with_name ( gui_simple_message_to_u
         utf8stringbuf_append_str( (*this_).private_temp_str, "Chosen database file could not be opened/created:\n" );
         utf8stringbuf_append_str( (*this_).private_temp_str, name );
     }
+    else if ( content_id == GUI_SIMPLE_MESSAGE_CONTENT_DB_FILE_NOT_CREATEABLE )
+    {
+        TSLOG_EVENT( "GUI_SIMPLE_MESSAGE_CONTENT_DB_FILE_NOT_CREATEABLE" );
+        utf8stringbuf_append_str( (*this_).private_temp_str,
+                                  "Database file could not be created, the parent directory is possibly read-only:\n"
+                                );
+        utf8stringbuf_append_str( (*this_).private_temp_str, name );
+    }
     else if ( content_id == GUI_SIMPLE_MESSAGE_CONTENT_DB_FILE_OPENED_WITH_ERROR )
     {
         TSLOG_EVENT( "GUI_SIMPLE_MESSAGE_CONTENT_DB_FILE_OPENED_WITH_ERROR" );
@@ -302,7 +313,9 @@ void gui_simple_message_to_user_show_message_with_name ( gui_simple_message_to_u
     else if ( content_id == GUI_SIMPLE_MESSAGE_CONTENT_NAME_NOT_UNIQUE )
     {
         TSLOG_EVENT( "GUI_SIMPLE_MESSAGE_CONTENT_NAME_NOT_UNIQUE" );
-        utf8stringbuf_append_str( (*this_).private_temp_str, "Name already in use (use copy and paste to insert the existing object): " );
+        utf8stringbuf_append_str( (*this_).private_temp_str,
+                                  "Name already in use (use copy and paste to insert the existing object): "
+                                );
         utf8stringbuf_append_str( (*this_).private_temp_str, name );
     }
     else if ( content_id == GUI_SIMPLE_MESSAGE_CONTENT_LOADING_WAIT )
@@ -323,6 +336,7 @@ void gui_simple_message_to_user_show_message_with_name ( gui_simple_message_to_u
         assert(false);
     }
     gtk_label_set_text ( GTK_LABEL( (*this_).text_label ), utf8stringbuf_get_string( (*this_).private_temp_str ));
+    TRACE_INFO_STR( "error at", name );
 
     /* show: */
     gtk_widget_show( GTK_WIDGET ( (*this_).text_label ) );
@@ -575,6 +589,31 @@ void gui_simple_message_to_user_private_append_stat ( gui_simple_message_to_user
     TRACE_END();
 }
 
+void gui_simple_message_to_user_show_error_info ( gui_simple_message_to_user_t *this_, const u8_error_info_t *err_info )
+{
+    TRACE_BEGIN();
+
+    /* update type id: */
+    (*this_).type_id = GUI_SIMPLE_MESSAGE_TYPE_ERROR;
+    gui_simple_message_to_user_private_set_icon_image( this_, GUI_SIMPLE_MESSAGE_TYPE_ERROR );
+
+    /* update content text: */
+    utf8stringbuf_clear( (*this_).private_temp_str );
+    {
+        gui_error_info_printer_t my_err_info_printer;
+        gui_error_info_printer_init( &my_err_info_printer );
+        gui_error_info_printer_show_error_info( &my_err_info_printer, err_info, (*this_).private_temp_str );
+        gui_error_info_printer_destroy( &my_err_info_printer );
+    }
+    gtk_label_set_text ( GTK_LABEL( (*this_).text_label ), utf8stringbuf_get_string( (*this_).private_temp_str ) );
+
+    /* show: */
+    gtk_widget_show( GTK_WIDGET ( (*this_).text_label ) );
+    gtk_widget_show( GTK_WIDGET ( (*this_).icon_image ) );
+
+    TRACE_END();
+}
+
 void gui_simple_message_to_user_hide ( gui_simple_message_to_user_t *this_ )
 {
     TRACE_BEGIN();
