@@ -3,9 +3,9 @@
 #include "io_export_set_traversal.h"
 
 #include "json/json_element_reader.h"
-#include "util/string/utf8string.h"
-#include "stream/universal_memory_output_stream.h"
-#include "trace.h"
+#include "utf8stringbuf/utf8string.h"
+#include "u8stream/universal_memory_output_stream.h"
+#include "trace/trace.h"
 #include <assert.h>
 #include <gtk/gtk.h>
 #include <stdbool.h>
