@@ -121,7 +121,10 @@ int json_element_writer_write_header( json_element_writer_t *this_, const char *
                                       );
 
     out_err |= json_writer_write_member_string( &((*this_).json_writer), 2, "encoding", "utf-8", true );
-    out_err |= json_writer_write_member_string( &((*this_).json_writer), 2, "structure_format", "rfc-8259", true );
+    /* hexadecimal escapes are complex: */
+    /* a single 6-byte sequence can only encode a codepoint of the the basic multilingual plane, */
+    /* two of these 6-byte sequences may form a surrogate pair */
+    out_err |= json_writer_write_member_string( &((*this_).json_writer), 2, "structure_format", "rfc-8259 w/o hexadecimal escapes", true );
     out_err |= json_writer_write_member_string( &((*this_).json_writer), 2, "format", "cfu-json", true );
     out_err |= json_writer_write_member_int( &((*this_).json_writer), 2, "major_version", 1, true );
     out_err |= json_writer_write_member_int( &((*this_).json_writer), 2, "minor_version", 0, true );
@@ -766,24 +769,6 @@ int json_element_writer_assemble_relationship( json_element_writer_t *this_,
                                                  true
                                                );
 
-        /* from_classifier_id */
-        out_err |= json_writer_write_plain( &((*this_).json_writer),
-                                            JSON_CONSTANTS_TAB
-                                            JSON_CONSTANTS_TAB
-                                            JSON_CONSTANTS_TAB
-                                            JSON_CONSTANTS_TAB
-                                            JSON_CONSTANTS_QUOTE
-                                            JSON_CONSTANTS_KEY_RELATIONSHIP_FROM_CLASSIFIER_ID
-                                            JSON_CONSTANTS_QUOTE
-                                            JSON_CONSTANTS_DEF
-                                          );
-        out_err |= json_writer_write_int( &((*this_).json_writer),
-                                          data_relationship_get_from_classifier_row_id( relation_ptr )
-                                        );
-        out_err |= json_writer_write_plain( &((*this_).json_writer),
-                                            JSON_CONSTANTS_NEXT_NL
-                                          );
-
         /* from_classifier_name */
         const char *const from_c_name = from_c_valid ? data_classifier_get_name_const( from_c ) : "";
         out_err |= json_writer_write_plain( &((*this_).json_writer),
@@ -803,61 +788,6 @@ int json_element_writer_assemble_relationship( json_element_writer_t *this_,
                                             JSON_CONSTANTS_NEXT_NL
                                           );
 
-        /* to_classifier_id */
-        out_err |= json_writer_write_plain( &((*this_).json_writer),
-                                            JSON_CONSTANTS_TAB
-                                            JSON_CONSTANTS_TAB
-                                            JSON_CONSTANTS_TAB
-                                            JSON_CONSTANTS_TAB
-                                            JSON_CONSTANTS_QUOTE
-                                            JSON_CONSTANTS_KEY_RELATIONSHIP_TO_CLASSIFIER_ID
-                                            JSON_CONSTANTS_QUOTE
-                                            JSON_CONSTANTS_DEF
-                                          );
-        out_err |= json_writer_write_int( &((*this_).json_writer),
-                                          data_relationship_get_to_classifier_row_id( relation_ptr )
-                                        );
-        out_err |= json_writer_write_plain( &((*this_).json_writer),
-                                            JSON_CONSTANTS_NEXT_NL
-                                          );
-
-        /* to_classifier_name */
-        const char *const to_c_name = to_c_valid ? data_classifier_get_name_const( to_c ) : "";
-        out_err |= json_writer_write_plain( &((*this_).json_writer),
-                                            JSON_CONSTANTS_TAB
-                                            JSON_CONSTANTS_TAB
-                                            JSON_CONSTANTS_TAB
-                                            JSON_CONSTANTS_TAB
-                                            JSON_CONSTANTS_QUOTE
-                                            JSON_CONSTANTS_KEY_RELATIONSHIP_TO_CLASSIFIER_NAME
-                                            JSON_CONSTANTS_QUOTE
-                                            JSON_CONSTANTS_DEF
-                                            JSON_CONSTANTS_QUOTE
-                                          );
-        out_err |= json_writer_write_string_enc( &((*this_).json_writer), to_c_name );
-        out_err |= json_writer_write_plain( &((*this_).json_writer),
-                                            JSON_CONSTANTS_QUOTE
-                                            JSON_CONSTANTS_NEXT_NL
-                                          );
-
-        /* from_feature_id */
-        out_err |= json_writer_write_plain( &((*this_).json_writer),
-                                            JSON_CONSTANTS_TAB
-                                            JSON_CONSTANTS_TAB
-                                            JSON_CONSTANTS_TAB
-                                            JSON_CONSTANTS_TAB
-                                            JSON_CONSTANTS_QUOTE
-                                            JSON_CONSTANTS_KEY_RELATIONSHIP_FROM_FEATURE_ID
-                                            JSON_CONSTANTS_QUOTE
-                                            JSON_CONSTANTS_DEF
-                                          );
-        out_err |= json_writer_write_int( &((*this_).json_writer),
-                                          data_relationship_get_from_feature_row_id( relation_ptr )
-                                        );
-        out_err |= json_writer_write_plain( &((*this_).json_writer),
-                                            JSON_CONSTANTS_NEXT_NL
-                                          );
-
         /* from_feature_key */
         if ( from_f_valid )
         {
@@ -881,21 +811,22 @@ int json_element_writer_assemble_relationship( json_element_writer_t *this_,
                                               );
         }
 
-        /* to_feature_id */
+        /* to_classifier_name */
+        const char *const to_c_name = to_c_valid ? data_classifier_get_name_const( to_c ) : "";
         out_err |= json_writer_write_plain( &((*this_).json_writer),
                                             JSON_CONSTANTS_TAB
                                             JSON_CONSTANTS_TAB
                                             JSON_CONSTANTS_TAB
                                             JSON_CONSTANTS_TAB
                                             JSON_CONSTANTS_QUOTE
-                                            JSON_CONSTANTS_KEY_RELATIONSHIP_TO_FEATURE_ID
+                                            JSON_CONSTANTS_KEY_RELATIONSHIP_TO_CLASSIFIER_NAME
                                             JSON_CONSTANTS_QUOTE
                                             JSON_CONSTANTS_DEF
+                                            JSON_CONSTANTS_QUOTE
                                           );
-        out_err |= json_writer_write_int( &((*this_).json_writer),
-                                          data_relationship_get_to_feature_row_id( relation_ptr )
-                                        );
+        out_err |= json_writer_write_string_enc( &((*this_).json_writer), to_c_name );
         out_err |= json_writer_write_plain( &((*this_).json_writer),
+                                            JSON_CONSTANTS_QUOTE
                                             JSON_CONSTANTS_NEXT_NL
                                           );
 
@@ -1063,37 +994,6 @@ int json_element_writer_assemble_diagram( json_element_writer_t *this_,
                                                  true
                                                );
 
-        /* parent_id */
-        out_err |= json_writer_write_plain( &((*this_).json_writer),
-                                            JSON_CONSTANTS_TAB
-                                            JSON_CONSTANTS_TAB
-                                            JSON_CONSTANTS_TAB
-                                            JSON_CONSTANTS_TAB
-                                            JSON_CONSTANTS_QUOTE
-                                            JSON_CONSTANTS_KEY_DIAGRAM_PARENT_ID
-                                            JSON_CONSTANTS_QUOTE
-                                            JSON_CONSTANTS_DEF
-                                          );
-        out_err |= json_writer_write_int( &((*this_).json_writer),
-                                          data_diagram_get_parent_row_id( diag_ptr )
-                                        );
-        out_err |= json_writer_write_plain( &((*this_).json_writer),
-                                            JSON_CONSTANTS_NEXT_NL
-                                          );
-
-        const bool parent_valid = ( parent == NULL ) ? false : data_diagram_is_valid( parent );
-
-        /* parent_name */
-        if( parent_valid )
-        {
-            out_err |= json_writer_write_member_string( &((*this_).json_writer),
-                                                        4,
-                                                        JSON_CONSTANTS_KEY_DIAGRAM_PARENT_NAME,
-                                                        data_diagram_get_name_const( parent ),
-                                                        true
-                                                    );
-        }
-
         /* diagram type */
         out_err |= json_writer_write_plain( &((*this_).json_writer),
                                             JSON_CONSTANTS_TAB
@@ -1171,6 +1071,19 @@ int json_element_writer_assemble_diagram( json_element_writer_t *this_,
                                                       );
         }
 
+        const bool parent_valid = ( parent == NULL ) ? false : data_diagram_is_valid( parent );
+
+        /* parent_name */
+        if( parent_valid )
+        {
+            out_err |= json_writer_write_member_string( &((*this_).json_writer),
+                                                        4,
+                                                        JSON_CONSTANTS_KEY_DIAGRAM_PARENT_NAME,
+                                                        data_diagram_get_name_const( parent ),
+                                                        true
+                                                    );
+        }
+
         /* parent uuid */
         if ( parent_valid )
         {
@@ -1365,26 +1278,6 @@ int json_element_writer_assemble_diagramelement( json_element_writer_t *this_,
                                                       );
         }
 
-        /* classifier_id */
-        out_err |= json_writer_write_plain( &((*this_).json_writer),
-                                            JSON_CONSTANTS_TAB
-                                            JSON_CONSTANTS_TAB
-                                            JSON_CONSTANTS_TAB
-                                            JSON_CONSTANTS_TAB
-                                            JSON_CONSTANTS_TAB
-                                            JSON_CONSTANTS_TAB
-                                            JSON_CONSTANTS_QUOTE
-                                            JSON_CONSTANTS_KEY_DIAGRAMELEMENT_CLASSIFIER_ID
-                                            JSON_CONSTANTS_QUOTE
-                                            JSON_CONSTANTS_DEF
-                                          );
-        out_err |= json_writer_write_int( &((*this_).json_writer),
-                                          data_diagramelement_get_classifier_row_id( diagramelement_ptr )
-                                        );
-        out_err |= json_writer_write_plain( &((*this_).json_writer),
-                                            JSON_CONSTANTS_NEXT_NL
-                                          );
-
         /* classifier_name */
         out_err |= json_writer_write_member_string( &((*this_).json_writer),
                                                     6,
@@ -1393,40 +1286,8 @@ int json_element_writer_assemble_diagramelement( json_element_writer_t *this_,
                                                     true
                                                   );
 
-        /* focused_feature_id */
-        out_err |= json_writer_write_plain( &((*this_).json_writer),
-                                            JSON_CONSTANTS_TAB
-                                            JSON_CONSTANTS_TAB
-                                            JSON_CONSTANTS_TAB
-                                            JSON_CONSTANTS_TAB
-                                            JSON_CONSTANTS_TAB
-                                            JSON_CONSTANTS_TAB
-                                            JSON_CONSTANTS_QUOTE
-                                            JSON_CONSTANTS_KEY_DIAGRAMELEMENT_FOCUSED_FEATURE_ID
-                                            JSON_CONSTANTS_QUOTE
-                                            JSON_CONSTANTS_DEF
-                                          );
-        out_err |= json_writer_write_int( &((*this_).json_writer),
-                                          data_diagramelement_get_focused_feature_row_id( diagramelement_ptr )
-                                        );
-        out_err |= json_writer_write_plain( &((*this_).json_writer),
-                                            JSON_CONSTANTS_NEXT_NL
-                                          );
-
         /* focused_feature_name */
         /* note that focused features are always lifelines and these never have names */
-#if 0
-        const bool feature_valid = ( feat_occur == NULL ) ? false : data_feature_is_valid( feat_occur );
-        if ( feature_valid )
-        {
-            out_err |= json_writer_write_member_string( &((*this_).json_writer),
-                                                        6,
-                                                        JSON_CONSTANTS_KEY_DIAGRAMELEMENT_FOCUSED_FEATURE_NAME,
-                                                        data_feature_get_key_const( feat_occur ),
-                                                        true
-                                                      );
-        }
-#endif
 
         /* ref_uuid */
         const bool feat_valid = ( feat_occur == NULL ) ? false : data_feature_is_valid( feat_occur );
