@@ -4,10 +4,10 @@
 #include "xmi/xmi_element_info.h"
 #include "xmi/xmi_element_info_map.h"
 #include "xmi/xmi_xml.h"
-#include "util/string/utf8string.h"
+#include "utf8stringbuf/utf8string.h"
 #include "data_id.h"
-#include "trace.h"
-#include "tslog.h"
+#include "trace/trace.h"
+#include "tslog/tslog.h"
 #include <stdbool.h>
 #include <assert.h>
 
