@@ -14,9 +14,9 @@
 #include "pencil_classifier_composer.h"
 #include "pencil_size.h"
 #include "pencil_layout_data.h"
-#include "util/geometry/geometry_rectangle.h"
-#include "util/geometry/geometry_h_align.h"
-#include "util/geometry/geometry_v_align.h"
+#include "geometry/geometry_rectangle.h"
+#include "geometry/geometry_h_align.h"
+#include "geometry/geometry_v_align.h"
 #include "data_diagram.h"
 #include "set/data_small_set.h"
 #include "data_id.h"
