@@ -1,11 +1,11 @@
 /* File: draw_feature_label.c; Copyright and License: see below */
 
 #include "draw/draw_feature_label.h"
-#include "trace.h"
+#include "trace/trace.h"
 #include "data_classifier.h"
 #include "data_diagramelement.h"
-#include "util/string/utf8stringbuf.h"
-#include "util/string/utf8string.h"
+#include "utf8stringbuf/utf8stringbuf.h"
+#include "utf8stringbuf/utf8string.h"
 #include <pango/pangocairo.h>
 #include <stdio.h>
 #include <stdlib.h>
